@@ -2,7 +2,7 @@
 #include "ErrorWarning.h"
 #include "BAMfunctions.h"
 
-void BAMbinSortUnmapped(uint32 iBin, uint nThreads, string dirBAMsort, Parameters &P, Genome &mapGen) {
+void BAMbinSortUnmapped(uint32 iBin, uint nThreads, string dirBAMsort, Parameters &P, Genome &mapGen, Solo &solo) {
 
     BGZF *bgzfBin;
     bgzfBin=bgzf_open((dirBAMsort+"/b"+to_string((uint) iBin)).c_str(),("w"+to_string((long long) P.outBAMcompression)).c_str());
@@ -37,24 +37,35 @@ void BAMbinSortUnmapped(uint32 iBin, uint nThreads, string dirBAMsort, Parameter
         bamInStream[it].read(bamIn[it],sizeof(int32));//read BAM record size
         if (bamInStream[it].good()) {
             bamSize[it]=((*(uint32*)bamIn[it])+sizeof(int32));//true record size +=4 (4 bytes for uint-iRead)
-            bamInStream[it].read(bamIn[it]+sizeof(int32),bamSize.at(it)-sizeof(int32)+sizeof(uint));//read the rest of the record, including last uint = iRead
-            startPos[*(uint*)(bamIn[it]+bamSize.at(it))]=it;//startPos[iRead]=it : record the order of the files to output
+            bamInStream[it].read(bamIn[it]+sizeof(int32),bamSize.at(it)-sizeof(int32)+sizeof(uint64));//read the rest of the record, including last uint = iRead
+            uint64 iRead=*(uint*)(bamIn[it]+bamSize.at(it));
+            iRead = iRead >> 32; //iRead is recorded in top 32bits
+            startPos[iRead]=it;//startPos[iRead]=it : record the order of the files to output
         } else {//nothing to do here, file is empty, do not record it
         };
     };
 
     //send ordered aligns to bgzf one-by-one
+    char bam1[BAM_ATTR_MaxSize];//temp array
     while (startPos.size()>0) {
         uint it=startPos.begin()->second;
         uint startNext=startPos.size()>1 ? (++startPos.begin())->first : (uint) -1;
 
         while (true) {
-            bgzf_write(bgzfBin, bamIn[it], bamSize.at(it));
+            //add extra tags to the BAM record
+            char* bam0=bamIn[it];
+            uint32 size0=bamSize.at(it);
+            
+            if (solo.pSolo.samAttrYes)
+                solo.soloFeat[solo.pSolo.samAttrFeature]->addBAMtags(bam0,size0,bam1);            
+            
+            bgzf_write(bgzfBin, bam0, size0);
             bamInStream[it].read(bamIn[it],sizeof(int32));//read record size
             if (bamInStream[it].good()) {
                  bamSize[it]=((*(uint32*)bamIn[it])+sizeof(int32));
-                 bamInStream[it].read(bamIn[it]+sizeof(int32),bamSize.at(it)-sizeof(int32)+sizeof(uint));//read the rest of the record, including la$
-                 uint iRead=*(uint*)(bamIn[it]+bamSize.at(it));
+                 bamInStream[it].read(bamIn[it]+sizeof(int32),bamSize.at(it)-sizeof(int32)+sizeof(uint));//read the rest of the record, including 
+                 uint64 iRead=*(uint*)(bamIn[it]+bamSize.at(it));
+                 iRead = iRead >> 32; //iRead is recorded in top 32bits
                  if (iRead>startNext) {//this read from this chunk is > than a read from another chunk
                      startPos[iRead]=it;
                      break;
