@@ -23,8 +23,8 @@ class ChimericAlign
         int chimMotif, chimStr, chimScore;
 
         ChimericAlign(ChimericSegment &seg1in, ChimericSegment &seg2in, int chimScoreIn, Genome &genomeIn, ReadAlign *RAin); //allocate
-        void chimericJunctionOutput(fstream &outStream, uint chimN);
-        void chimericStitching(char *genSeq, char *readSeq);
+        void chimericJunctionOutput(fstream &outStream, uint chimN, int maxNonChimAlignScore, bool PEmerged_flag, int chimScoreBest, int maxPossibleAlignScore);
+        void chimericStitching(char *genSeq, char **Read1);
         bool chimericCheck();
 
         bool stitchingDone;
@@ -37,4 +37,4 @@ class ChimericAlign
 
 };
 
-#endif
\ No newline at end of file
+#endif
