@@ -95,7 +95,10 @@ void ReadAlign::copyRead(ReadAlign &r) {//copy read information only
     readLengthPairOriginal=r.readLengthPairOriginal;
     outFilterMismatchNmaxTotal=r.outFilterMismatchNmaxTotal;
     readName=r.readName;
-
+    iReadAll=r.iReadAll;
+    readFilter=r.readFilter;
+    readFilesIndex=r.readFilesIndex;
+    
     for (uint ii=0;ii<=2;ii++)
         memcpy(Read1[ii],r.Read1[ii],Lread);//need to copy since it will be changed
     Qual1=r.Qual1;
