@@ -10,8 +10,8 @@ SoloReadBarcode::SoloReadBarcode(Parameters &Pin) : P(Pin), pSolo(P.pSolo)
         stats.V[ii]=0;
 
     if (pSolo.cbWLyes) {
-        cbReadCountExact = new uint32[pSolo.cbWL.size()];
-        for (uint32 ii=0; ii<pSolo.cbWL.size(); ii++) {
+        cbReadCountExact = new uint32[pSolo.cbWLsize];
+        for (uint32 ii=0; ii<pSolo.cbWLsize; ii++) {
             cbReadCountExact[ii]=0;
         };
     };
@@ -27,7 +27,7 @@ SoloReadBarcode::SoloReadBarcode(Parameters &Pin) : P(Pin), pSolo(P.pSolo)
 void SoloReadBarcode::addCounts(const SoloReadBarcode &rfIn)
 {
     if (pSolo.cbWLyes) {
-        for (uint32 ii=0; ii<pSolo.cbWL.size(); ii++) {
+        for (uint32 ii=0; ii<pSolo.cbWLsize; ii++) {
             cbReadCountExact[ii] += rfIn.cbReadCountExact[ii];
         };
     };
