@@ -25,6 +25,9 @@ class Stats {
 
         time_t timeStart, timeStartMap, timeFinishMap, timeLastReport, timeFinish;
 
+        //quality
+        array<array<uint64,256>,2> qualHist;
+        
         Stats ();
         void resetN();
         void printShort(ostream*);
@@ -34,5 +37,7 @@ class Stats {
         void progressReport(ofstream &progressStream) ;
         void reportFinal(ofstream &streamOut);
         void writeLines(ofstream &streamOut, const vector<int> outType, const string commStr, const string outStr);// write commented lines to text files with stats
+        
+        void qualHistCalc(const uint64 imate, const char* qual, const uint64 len);
 };
 #endif
