@@ -9,7 +9,7 @@ template <class T>
         for (uint ii=0;ii<N;ii++) s+=a[ii];
         return s;
     };
-    
+
 template <class numT> int funCompareNumbers (const void *a, const void *b) {
     numT va= *((numT*) a);
     numT vb= *((numT*) b);
@@ -35,8 +35,8 @@ template <class numT> int funCompareNumbersReverse (const void *a, const void *b
         return 1;
     };
 };
-    
-    
+
+
 inline int funCompareUint1 (const void *a, const void *b) {
     uint va= *((uint*) a);
     uint vb= *((uint*) b);
@@ -157,20 +157,20 @@ inline int32 binarySearch1a(argType x, argType *X, int32 N) {
 };
 
 template <class argType>
-inline int32 binarySearch1b(argType x, argType *X, int32 N) 
+inline int32 binarySearch1b(argType x, argType *X, int32 N)
 {
     //binary search in the sorted list
     //check the boundaries first
     //1b returns the first X element that is >= x
     //X are all distinct
     //if x>X[N-1], -1 is returned
-    
+
     if (x>X[N-1]) {
         return -1;
     } else if (x<=X[0]) {
         return 0;
     };
-    
+
     int32 i1=0, i2=N-1, i3=N/2;
     while (i2>i1+1) {//binary search
         i3=(i1+i2)/2;
@@ -180,21 +180,21 @@ inline int32 binarySearch1b(argType x, argType *X, int32 N)
             i1=i3;
         };
     };
-    
+
     return i2;
 };
 
 template <class argType>
-inline int32 binarySearchExact(argType x, argType *X, int32 N) {
+inline int64 binarySearchExact(argType x, argType *X, uint64 N) {
     //binary search in the sorted list
     //check the boundaries first
     //returns -1 if no match found
     //if X are not all distinct, no guarantee which element is returned
-    
-    if (x>X[N-1] || x<X[0]) 
+
+    if (x>X[N-1] || x<X[0])
         return -1;
 
-    
+
     int32 i1=0, i2=N-1, i3=N/2;
     while (i2>i1+1) {//binary search
         i3=(i1+i2)/2;
@@ -204,9 +204,9 @@ inline int32 binarySearchExact(argType x, argType *X, int32 N) {
             i1=i3;
         };
     };
-    
+
     if (x==X[i2]) {
-        return i2;        
+        return i2;
     } else if (x==X[i1]) {
         return i1;
     } else {
