@@ -6,7 +6,7 @@
 #include "ReadAlign.h"
 
 void stitchWindowAligns(uint iA, uint nA, int Score, bool WAincl[], uint tR2, uint tG2, Transcript trA, \
-                        uint Lread, uiWA* WA, char* R, char* Q, char* G, char* sigG,\
-                        Parameters* P, Transcript** wTr, uint* nWinTr, ReadAlign *RA);
+                        uint Lread, uiWA* WA, char* R, Genome &mapGen, \
+                        Parameters& P, Transcript** wTr, uint* nWinTr, ReadAlign *RA);
     //recursively stitch aligns for one gene
     //*nWinTr - number of transcripts for the current window
